<?php

namespace Drupal\kinescope\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use GuzzleHttp\Client;
use GuzzleHttp\Exception\RequestException;

/**
 * General settings form Kinescope.
 */
class KinescopeSettingsForm extends ConfigFormBase {

  /**
   * The config settings name.
   *
   * @var string Config settings
   */

  const SETTINGS = 'kinescope.settings';

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [static::SETTINGS];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'kinescope_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(static::SETTINGS)->get('kinescope');

    $form['kinescope'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Kinescope credentials'),
      '#tree' => TRUE,
    ];

    $form['kinescope']['api_token'] = [
      '#title' => $this->t('API token'),
      '#type' => 'textfield',
      '#description' => $this->t('<a href="https://app.kinescope.io/workspace/api_token" target="_blank">The API token</a> from Kinescope site.'),
      '#required' => TRUE,
      '#default_value' => !empty($config['api_token']) ? $config['api_token'] : '',
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);
    $values = $form_state->getValues();
    $client = new Client();
    try {
      $response = $client->get('https://api.kinescope.io/v1/videos', [
        'headers' => [
          'Accept' => 'application/json',
          'Authorization' => 'Bearer ' . $values['kinescope']['api_token'],
        ],
      ]);
      json_decode($response->getBody(), TRUE);
    }
    catch (RequestException $e) {
      $form_state->setErrorByName(
        'api_token',
        $this->t("The API Token isn't saved, error: @error",
          ['@error' => $e->getMessage()]
      ));
    }

  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $values = $form_state->getValues();
    $this->config(static::SETTINGS)
      ->set("kinescope", $values['kinescope'])
      ->save();
    parent::submitForm($form, $form_state);
  }

}
